Learn R Programming

topologyR (version 0.1.2)

calculate_thresholds: Calculate multiple threshold methods for topology analysis

Description

Calculate multiple threshold methods for topology analysis

Usage

calculate_thresholds(data)

Value

A named list containing five threshold values:

mean_diff

Numeric. Threshold based on mean of absolute differences between adjacent sorted values.

median_diff

Numeric. Threshold based on median of absolute differences between adjacent sorted values.

sd

Numeric. Threshold based on standard deviation of the data.

iqr

Numeric. Threshold based on IQR divided by 4.

dbscan

Numeric. Threshold based on DBSCAN-like density estimation using k-th nearest neighbor distance.

Arguments

data

Numeric vector to calculate thresholds for