Learn R Programming

topologyR (version 0.1.2)

is_topology_connected2: Check if a topology is connected using directed graph approach

Description

Check if a topology is connected using directed graph approach

Usage

is_topology_connected2(topology)

Value

logical scalar. Returns TRUE if the topology is connected through directed graph traversal (considering sequential connections between elements), FALSE otherwise. Returns FALSE if the topology is empty.

Arguments

topology

A list of sets representing the topology

Examples

Run this code
topology <- list(c(1,2,3), c(3,4,5))
is_topology_connected2(topology)

Run the code above in your browser using DataLab