Learn R Programming

topologyR (version 0.1.2)

is_topology_connected_manual: Check if a topology is connected using manual checking approach

Description

Check if a topology is connected using manual checking approach

Usage

is_topology_connected_manual(topology)

Value

logical scalar. Returns TRUE if all elements from 1 to the maximum value in the topology are present in at least one set, FALSE otherwise.

Arguments

topology

A list of sets representing the topology

Examples

Run this code
topology <- list(c(1,2,3), c(3,4,5))
is_topology_connected_manual(topology)

Run the code above in your browser using DataLab