Calculate multiple threshold methods for topology analysis
calculate_thresholds(data)A named list containing five threshold values:
Numeric. Threshold based on mean of absolute differences between adjacent sorted values.
Numeric. Threshold based on median of absolute differences between adjacent sorted values.
Numeric. Threshold based on standard deviation of the data.
Numeric. Threshold based on IQR divided by 4.
Numeric. Threshold based on DBSCAN-like density estimation using k-th nearest neighbor distance.
Numeric vector to calculate thresholds for