powered by
Check if a topology is connected using manual checking approach
is_topology_connected_manual(topology)
logical scalar. Returns TRUE if all elements from 1 to the maximum value in the topology are present in at least one set, FALSE otherwise.
logical
TRUE
FALSE
A list of sets representing the topology
topology <- list(c(1,2,3), c(3,4,5)) is_topology_connected_manual(topology)
Run the code above in your browser using DataLab